@@ -314,26 +314,16 @@ object_info_free (gpointer data)
        * unless we are unmerging in which case we have to destroy
        * the actor to unparent them
        */
-      if (oinfo->object)
+      if (oinfo->object != NULL)
         {
           if (oinfo->is_unmerged)
             {
-              if (oinfo->is_toplevel)
-                g_object_unref (oinfo->object);
-              else
-                {
-                  /* destroy every actor, unless it's the default stage */
-                  if (oinfo->is_stage_default == FALSE &&
-                      CLUTTER_IS_ACTOR (oinfo->object))
-                    clutter_actor_destroy (CLUTTER_ACTOR (oinfo->object));
-                }
-            }
-          else
-            {
-              if (oinfo->is_toplevel)
-                g_object_unref (oinfo->object);
+              if (oinfo->is_actor && !oinfo->is_stage)
+                clutter_actor_destroy (CLUTTER_ACTOR (oinfo->object));
             }
 
+          g_object_unref (oinfo->object);
+
           oinfo->object = NULL;
         }
 
@@ -380,15 +370,11 @@ static void
 clutter_script_class_init (ClutterScriptClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
-  GParamSpec *pspec;
 
   g_type_class_add_private (klass, sizeof (ClutterScriptPrivate));
 
   klass->get_type_from_name = clutter_script_real_get_type_from_name;
 
-  gobject_class->get_property = clutter_script_get_property;
-  gobject_class->finalize = clutter_script_finalize;
-
   /**
    * ClutterScript:filename-set:
    *
@@ -398,13 +384,12 @@ clutter_script_class_init (ClutterScriptClass *klass)
    *
    * Since: 0.6
    */
-  pspec = g_param_spec_boolean ("filename-set",
-                                P_("Filename Set"),
-                                P_("Whether the :filename property is set"),
-                                FALSE,
-                                CLUTTER_PARAM_READABLE);
-  obj_props[PROP_FILENAME_SET] = pspec;
-  g_object_class_install_property (gobject_class, PROP_FILENAME_SET, pspec);
+  obj_props[PROP_FILENAME_SET] =
+    g_param_spec_boolean ("filename-set",
+                          P_("Filename Set"),
+                          P_("Whether the :filename property is set"),
+                          FALSE,
+                          CLUTTER_PARAM_READABLE);
 
   /**
    * ClutterScript:filename:
@@ -414,13 +399,19 @@ clutter_script_class_init (ClutterScriptClass *klass)
    *
    * Since: 0.6
    */
-  pspec = g_param_spec_string ("filename",
-                               P_("Filename"),
-                               P_("The path of the currently parsed file"),
-                               NULL,
-                               CLUTTER_PARAM_READABLE);
-  obj_props[PROP_FILENAME] = pspec;
-  g_object_class_install_property (gobject_class, PROP_FILENAME, pspec);
+  obj_props[PROP_FILENAME] =
+    g_param_spec_string ("filename",
+                         P_("Filename"),
+                         P_("The path of the currently parsed file"),
+                         NULL,
+                         CLUTTER_PARAM_READABLE);
+
+  gobject_class->get_property = clutter_script_get_property;
+  gobject_class->finalize = clutter_script_finalize;
+
+  _clutter_object_class_install_properties (gobject_class,
+                                            PROP_LAST,
+                                            obj_props);
 }
 
 static void
@@ -521,7 +512,7 @@ clutter_script_load_from_file (ClutterScript  *script,
  *
  * Return value: on error, zero is returned and @error is set
  *   accordingly. On success, the merge id for the UI definitions is
- *   returned. You can use the merge id with clutter_script_unmerge().
+ *   returned. You can use the merge id with clutter_script_unmerge_objects().
  *
  * Since: 0.6
  */
@@ -569,7 +560,7 @@ clutter_script_load_from_data (ClutterScript  *script,
  * Retrieves the object bound to @name. This function does not increment
  * the reference count of the returned object.
  *
- * Return value: : (transfer none): the named object, or %NULL if no object
+ * Return value: (transfer none): the named object, or %NULL if no object
  *   with the given name was available
  *
  * Since: 0.6
@@ -1205,7 +1196,7 @@ _clutter_script_generate_fake_id (ClutterScript *script)
 /*
  * _clutter_script_warn_missing_attribute:
  * @script: a #ClutterScript
- * @id: the id of an object definition, or %NULL
+ * @id_: the id of an object definition, or %NULL
  * @attribute: the expected attribute
  *
  * Emits a warning, using GLib's log facilities, for a missing
@@ -1214,19 +1205,19 @@ _clutter_script_generate_fake_id (ClutterScript *script)
  */
 void
 _clutter_script_warn_missing_attribute (ClutterScript *script,
-                                        const gchar   *id,
+                                        const gchar   *id_,
                                         const gchar   *attribute)
 {
   ClutterScriptPrivate *priv = script->priv;
   JsonParser *parser = JSON_PARSER (priv->parser);
   gint current_line = json_parser_get_current_line (parser);
 
-  if (id != NULL && *id != '\0')
+  if (id_ != NULL && *id_ != '\0')
     {
       g_warning ("%s:%d: object '%s' has no '%s' attribute",
                  priv->is_filename ? priv->filename : "<input>",
                  current_line,
-                 id,
+                 id_,
                  attribute);
     }
   else
