@@ -3,6 +3,7 @@
  *
  * Copyright (C) 2007-2008  Tommi Komulainen <tommi.komulainen@iki.fi>
  * Copyright (C) 2007  OpenedHand Ltd.
+ * Copyright (C) 2011  Crystalnix <vgachkaylo@crystalnix.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,8 +23,10 @@
 #include "config.h"
 
 #include "clutter-osx.h"
+
 #include "clutter-backend-osx.h"
 #include "clutter-device-manager-osx.h"
+#include "clutter-shader.h"
 #include "clutter-stage-osx.h"
 
 #include "clutter-debug.h"
@@ -75,13 +78,13 @@ clutter_backend_osx_create_stage (ClutterBackend  *backend,
 {
   ClutterStageWindow *impl;
 
-  CLUTTER_NOTE (BACKEND, "create_stage: wrapper=%p", wrapper);
-
   CLUTTER_OSX_POOL_ALLOC();
 
   impl = _clutter_stage_osx_new (backend, wrapper);
 
-  CLUTTER_NOTE (BACKEND, "create_stage: impl=%p", impl);
+  CLUTTER_NOTE (BACKEND, "create_stage: wrapper=%p - impl=%p",
+                wrapper,
+                impl);
 
   CLUTTER_OSX_POOL_RELEASE();
 
@@ -95,7 +98,7 @@ clutter_backend_osx_create_device_manager (ClutterBackendOSX *backend_osx)
     return;
 
   backend_osx->device_manager = g_object_new (CLUTTER_TYPE_DEVICE_MANAGER_OSX,
-                                              "backend", backend,
+                                              "backend", CLUTTER_BACKEND(backend_osx),
                                               NULL);
 }
 
@@ -128,11 +131,13 @@ clutter_backend_osx_create_context (ClutterBackend  *backend,
                                     GError         **error)
 {
   ClutterBackendOSX *backend_osx = CLUTTER_BACKEND_OSX (backend);
+
   CLUTTER_OSX_POOL_ALLOC();
-  if ( backend_osx->context == nil)
+
+  if (backend_osx->context == nil)
     {
-      /* Allocate ourselves a GL context. Since we're supposed to have only one per
-       * backend we can just as well create it now.
+      /* Allocate ourselves a GL context. Since we're supposed to have
+       * only one per backend we can just as well create it now.
        */
       NSOpenGLPixelFormatAttribute attrs[] = {
         NSOpenGLPFADoubleBuffer,
@@ -140,21 +145,25 @@ clutter_backend_osx_create_context (ClutterBackend  *backend,
         NSOpenGLPFAStencilSize, 8,
         0
       };
-      
-      backend_osx->pixel_format = [[NSOpenGLPixelFormat alloc] initWithAttributes:attrs];
-      backend_osx->context = [[NSOpenGLContext alloc]
-                              initWithFormat: backend_osx->pixel_format
-                              shareContext: nil];
-      /* Enable vblank sync - http://developer.apple.com/qa/qa2007/qa1521.html */
+
 #ifdef MAC_OS_X_VERSION_10_5
       const int sw = 1;
 #else
       const long sw = 1;
 #endif
+
+      backend_osx->pixel_format = [[NSOpenGLPixelFormat alloc] initWithAttributes:attrs];
+      backend_osx->context = [[NSOpenGLContext alloc]
+                              initWithFormat: backend_osx->pixel_format
+                              shareContext: nil];
+      /* Enable vblank sync - http://developer.apple.com/qa/qa2007/qa1521.html */
       [backend_osx->context setValues:&sw forParameter: NSOpenGLCPSwapInterval];
     }
+
   [backend_osx->context makeCurrentContext];
+
   CLUTTER_NOTE (BACKEND, "Context was created");
+
   CLUTTER_OSX_POOL_RELEASE();
 
   return TRUE;
@@ -166,10 +175,10 @@ clutter_backend_osx_ensure_context (ClutterBackend *backend,
 {
   ClutterBackendOSX *backend_osx = CLUTTER_BACKEND_OSX (backend);
 
-  CLUTTER_NOTE (BACKEND, "ensure_context: wrapper=%p", wrapper);
-
   CLUTTER_OSX_POOL_ALLOC();
 
+  CLUTTER_NOTE (BACKEND, "ensure_context: wrapper=%p", wrapper);
+
   if (wrapper)
     {
       ClutterStageWindow *impl = _clutter_stage_get_window (wrapper);
@@ -190,31 +199,19 @@ clutter_backend_osx_ensure_context (ClutterBackend *backend,
   CLUTTER_OSX_POOL_RELEASE();
 }
 
-static void
-clutter_backend_osx_redraw (ClutterBackend *backend, ClutterStage *wrapper)
-{
-  ClutterStageWindow *impl = _clutter_stage_get_window (wrapper);
-  ClutterStageOSX *stage_osx = CLUTTER_STAGE_OSX (impl);
-
-  CLUTTER_OSX_POOL_ALLOC();
-
-  [stage_osx->view setNeedsDisplay: YES];
-
-  CLUTTER_OSX_POOL_RELEASE();
-}
-
 /*************************************************************************/
 
 static void
 clutter_backend_osx_init (ClutterBackendOSX *backend_osx)
 {
+  const ProcessSerialNumber psn = { 0, kCurrentProcess };
+
   backend_osx->context = nil;
   backend_osx->pixel_format = nil;
 
-/* Bring our app to foreground, background apps don't appear in dock or
+  /* Bring our app to foreground, background apps don't appear in dock or
    * accept keyboard focus.
    */
-  const ProcessSerialNumber psn = { 0, kCurrentProcess };
   TransformProcessType (&psn, kProcessTransformToForegroundApplication);
 
   /* Also raise our app to front, otherwise our window will remain under the
@@ -255,7 +252,6 @@ clutter_backend_osx_class_init (ClutterBackendOSXClass *klass)
   backend_class->create_context     = clutter_backend_osx_create_context;
   backend_class->ensure_context     = clutter_backend_osx_ensure_context;
   backend_class->init_events        = clutter_backend_osx_init_events;
-  backend_class->redraw             = clutter_backend_osx_redraw;
   backend_class->get_device_manager = clutter_backend_osx_get_device_manager;
 }
 
